Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var React = tslib_1.__importStar(require("react"));
var react_router_1 = require("react-router");
var dataZoomInside_1 = tslib_1.__importDefault(require("app/components/charts/components/dataZoomInside"));
var toolBox_1 = tslib_1.__importDefault(require("app/components/charts/components/toolBox"));
var callIfFunction_1 = require("app/utils/callIfFunction");
var BarChartZoom = /** @class */ (function (_super) {
    tslib_1.__extends(BarChartZoom, _super);
    function BarChartZoom() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        /**
         * Enable zoom immediately instead of having to toggle to zoom
         */
        _this.handleChartReady = function (chart) {
            chart.dispatchAction({
                type: 'takeGlobalCursor',
                key: 'dataZoomSelect',
                dataZoomSelectActive: true,
            });
            callIfFunction_1.callIfFunction(_this.props.onChartReady, chart);
        };
        _this.handleDataZoom = function (evt, chart) {
            var _a;
            var model = chart.getModel();
            var xAxis = model.option.xAxis;
            var axis = xAxis[0];
            // Both of these values should not be null, but we include it just in case.
            // These values are null when the user uses the toolbox included in ECharts
            // to navigate back through zoom history, but we hide it below.
            if (axis.rangeStart !== null && axis.rangeEnd !== null) {
                var _b = _this.props, buckets = _b.buckets, location_1 = _b.location, paramStart = _b.paramStart, paramEnd = _b.paramEnd, minZoomWidth = _b.minZoomWidth, onHistoryPush = _b.onHistoryPush;
                var start = buckets[axis.rangeStart].start;
                var end = buckets[axis.rangeEnd].end;
                if (minZoomWidth === undefined || end - start > minZoomWidth) {
                    var target = {
                        pathname: location_1.pathname,
                        query: tslib_1.__assign(tslib_1.__assign({}, location_1.query), (_a = {}, _a[paramStart] = start, _a[paramEnd] = end, _a)),
                    };
                    if (onHistoryPush) {
                        onHistoryPush(start, end);
                    }
                    else {
                        react_router_1.browserHistory.push(target);
                    }
                }
                else {
                    // Dispatch the restore action here to stop ECharts from zooming
                    chart.dispatchAction({ type: 'restore' });
                    callIfFunction_1.callIfFunction(_this.props.onDataZoomCancelled);
                }
            }
            else {
                // Dispatch the restore action here to stop ECharts from zooming
                chart.dispatchAction({ type: 'restore' });
                callIfFunction_1.callIfFunction(_this.props.onDataZoomCancelled);
            }
            callIfFunction_1.callIfFunction(_this.props.onDataZoom, evt, chart);
        };
        return _this;
    }
    BarChartZoom.prototype.render = function () {
        var _a = this.props, children = _a.children, xAxisIndex = _a.xAxisIndex;
        var renderProps = {
            onChartReady: this.handleChartReady,
            dataZoom: dataZoomInside_1.default({ xAxisIndex: xAxisIndex }),
            // We must include data zoom in the toolbox for the zoom to work,
            // but we do not want to show the toolbox components.
            toolBox: toolBox_1.default({}, {
                dataZoom: {
                    title: {
                        zoom: '',
                        back: '',
                    },
                    iconStyle: {
                        borderWidth: 0,
                        color: 'transparent',
                        opacity: 0,
                    },
                },
            }),
            onDataZoom: this.handleDataZoom,
        };
        return children(renderProps);
    };
    return BarChartZoom;
}(React.Component));
exports.default = BarChartZoom;
//# sourceMappingURL=barChartZoom.jsx.map