Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var Sentry = tslib_1.__importStar(require("@sentry/react"));
var isUndefined_1 = tslib_1.__importDefault(require("lodash/isUndefined"));
var reflux_1 = tslib_1.__importDefault(require("reflux"));
/**
 * See types/hooks for hook usage reference.
 */
var validHookNames = new Set([
    '_',
    'analytics:event',
    'analytics:init-user',
    'analytics:track-adhoc-event',
    'analytics:track-event',
    'analytics:track-event-v2',
    'analytics:log-experiment',
    'component:disabled-member',
    'component:disabled-member-tooltip',
    'component:header-date-range',
    'component:header-selector-items',
    'component:global-notifications',
    'component:member-list-header',
    'component:dashboards-header',
    'feature-disabled:alerts-page',
    'feature-disabled:alert-wizard-performance',
    'feature-disabled:configure-distributed-tracing',
    'feature-disabled:custom-inbound-filters',
    'feature-disabled:custom-symbol-sources',
    'feature-disabled:data-forwarding',
    'feature-disabled:discard-groups',
    'feature-disabled:discover-page',
    'feature-disabled:discover-saved-query-create',
    'feature-disabled:discover-sidebar-item',
    'feature-disabled:discover2-page',
    'feature-disabled:discover2-sidebar-item',
    'feature-disabled:events-page',
    'feature-disabled:events-sidebar-item',
    'feature-disabled:grid-editable-actions',
    'feature-disabled:open-discover',
    'feature-disabled:dashboards-edit',
    'feature-disabled:dashboards-page',
    'feature-disabled:dashboards-sidebar-item',
    'feature-disabled:incidents-sidebar-item',
    'feature-disabled:performance-new-project',
    'feature-disabled:performance-page',
    'feature-disabled:performance-quick-trace',
    'feature-disabled:performance-sidebar-item',
    'feature-disabled:project-performance-score-card',
    'feature-disabled:project-selector-checkbox',
    'feature-disabled:rate-limits',
    'feature-disabled:sso-basic',
    'feature-disabled:sso-rippling',
    'feature-disabled:sso-saml2',
    'feature-disabled:trace-view-link',
    'footer',
    'help-modal:footer',
    'integrations:feature-gates',
    'member-invite-modal:customization',
    'metrics:event',
    'onboarding:extra-chrome',
    'onboarding-wizard:skip-help',
    'organization:header',
    'routes',
    'routes:admin',
    'routes:api',
    'routes:organization',
    'routes:organization-root',
    'settings:api-navigation-config',
    'settings:organization-navigation',
    'settings:organization-navigation-config',
    'sidebar:bottom-items',
    'sidebar:help-menu',
    'sidebar:item-label',
    'sidebar:item-override',
    'sidebar:organization-dropdown-menu',
    'sidebar:organization-dropdown-menu-bottom',
]);
var hookStoreConfig = {
    hooks: {},
    init: function () {
        this.hooks = {};
    },
    add: function (hookName, callback) {
        // Gracefully error on invalid hooks, but maintain registration
        // TODO(ts): With typescript we can remove this in the future
        if (!validHookNames.has(hookName)) {
            // eslint-disable-next-line no-console
            console.error('Invalid hook name: ' + hookName);
            Sentry.withScope(function (scope) {
                scope.setExtra('hookName', hookName);
                Sentry.captureException(new Error('Invalid hook name'));
            });
        }
        if (isUndefined_1.default(this.hooks[hookName])) {
            this.hooks[hookName] = [];
        }
        this.hooks[hookName].push(callback);
        this.trigger(hookName, this.hooks[hookName]);
    },
    remove: function (hookName, callback) {
        if (isUndefined_1.default(this.hooks[hookName])) {
            return;
        }
        this.hooks[hookName] = this.hooks[hookName].filter(function (cb) { return cb !== callback; });
        this.trigger(hookName, this.hooks[hookName]);
    },
    get: function (hookName) {
        return this.hooks[hookName] || [];
    },
};
/**
 * HookStore is used to allow extensibility into Sentry's frontend via
 * registration of 'hook functions'.
 *
 * This functionality is primarily used by the SASS sentry.io product.
 */
var HookStore = reflux_1.default.createStore(hookStoreConfig);
exports.default = HookStore;
//# sourceMappingURL=hookStore.jsx.map